"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stringEscape = (str) => str.replace(/[`"$]/g, '`$&');
const plainName = /^[a-zA-Z_]\w+$/;
const objectKey = (name) => plainName.test(name) ? name : `"${stringEscape(name)}"`;
const declareName = (name, lang) => {
    lang.invalid(plainName.test(name), name, 'name');
    return `$${name}`;
};
const reprBigInt = (val) => `[bigint]"${String(val)}"`;
const reprString = (val) => `"${stringEscape(val)}"`;
const reprDate = (val) => `$(Get-Date -Format o "${val.toISOString()}")`;
const language = {
    reprs: {
        string: reprString,
        bigint: reprBigInt,
        date: reprDate
    },
    consts: {
        // string representations of language
        // constants 'null' or undefined for unsupported
        true: '$true',
        false: '$false',
        null: '$null',
        invalid_date: '$null',
        nan: '[double]::NaN',
        positive_infinity: '[double]::PositiveInfinity',
        negative_infinity: '[double]::NegativeInfinity',
        undefined: '$null'
    },
    format: {
        indent: '  ',
        eol: '\n',
        declare: {
            name: declareName,
            start: '',
            assign: ' = ',
            end: '',
            sep: ';\n'
        },
        // 2 space indentation
        iterable: {
            sep: ', ',
            start: '@(',
            end: ')',
            // array of types that are valid
            valid: false,
            // array of types that are invalid
            invalid: false
        },
        object: {
            key: objectKey,
            sep: '; ',
            start: '@{',
            end: '}',
            assign: ' = ',
            // array of types that are valid
            valid: false,
            // array of types that are invalid
            invalid: false
            // break into new
            // into length
        }
    }
};
exports.default = language;
